"use strict";
/*
* Mbed Cloud JavaScript SDK
* Copyright Arm Limited 2017
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
var mbed_cloud_sdk_1 = require("mbed-cloud-sdk");
var GetCampaign = /** @class */ (function () {
    function GetCampaign(node, config, RED) {
        this.node = node;
        this.update = null;
        this.config = RED.nodes.getNode(config.config);
        if (this.config) {
            this.update = new mbed_cloud_sdk_1.UpdateApi({
                apiKey: this.config.credentials.apikey,
                host: this.config.host
            });
        }
        this.campaignId = config.campaignId;
        this.node.on("input", this.inputHandler.bind(this));
    }
    GetCampaign.prototype.inputHandler = function (msg) {
        var _this = this;
        var campaignId = this.campaignId || msg.campaignId;
        this.update.getCampaign(campaignId)
            .then(function (campaign) {
            msg.campaignId = campaignId;
            msg.payload = campaign;
            _this.node.send(msg);
        }).catch(function (error) {
            _this.node.status({
                fill: "red",
                shape: "ring",
                text: "Error retreiving campaign"
            });
            _this.node.error(error);
        });
    };
    return GetCampaign;
}());
module.exports = function (RED) {
    // tslint:disable-next-line:only-arrow-functions
    RED.nodes.registerType("get-campaign", function (config) {
        var node = this;
        RED.nodes.createNode(node, config);
        // tslint:disable-next-line:no-unused-expression
        new GetCampaign(node, config, RED);
    });
};
