"use strict";
/*
* Mbed Cloud JavaScript SDK
* Copyright Arm Limited 2017
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
var mbed_cloud_sdk_1 = require("mbed-cloud-sdk");
var ListQueries = /** @class */ (function () {
    function ListQueries(node, config, RED) {
        this.node = node;
        this.connect = null;
        this.config = RED.nodes.getNode(config.config);
        if (this.config) {
            this.connect = new mbed_cloud_sdk_1.DeviceDirectoryApi({
                apiKey: this.config.credentials.apikey,
                host: this.config.host
            });
        }
        this.limit = config.limit;
        this.order = config.order;
        this.after = config.after;
        this.include = config.include;
        this.node.on("input", this.inputHandler.bind(this));
    }
    ListQueries.prototype.inputHandler = function (msg) {
        var _this = this;
        var limit = this.limit || msg.limit;
        var order = this.order || msg.order;
        var after = this.after || msg.after;
        var include = this.include || msg.include;
        var filter = msg.filter;
        this.connect.listQueries({ limit: limit, order: order, after: after, include: include, filter: filter })
            .then(function (queries) {
            msg.payload = queries;
            _this.node.send(msg);
        }).catch(function (error) {
            _this.node.status({
                fill: "red",
                shape: "ring",
                text: "Error retreiving queries"
            });
            _this.node.error(error);
        });
    };
    return ListQueries;
}());
module.exports = function (RED) {
    // tslint:disable-next-line:only-arrow-functions
    RED.nodes.registerType("list-queries", function (config) {
        var node = this;
        RED.nodes.createNode(node, config);
        // tslint:disable-next-line:no-unused-expression
        new ListQueries(node, config, RED);
    });
};
