"use strict";
/*
* Mbed Cloud JavaScript SDK
* Copyright Arm Limited 2017
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
var connectApiManager_1 = require("../connectApiManager");
var SetResourceValue = /** @class */ (function () {
    function SetResourceValue(node, config, RED) {
        this.node = node;
        this.connect = null;
        this.config = RED.nodes.getNode(config.config);
        if (this.config) {
            this.connect = connectApiManager_1.ConnectApiManager.Instance(node, this.config);
        }
        this.deviceId = config.deviceId;
        this.resourceURI = config.resourceURI;
        this.payload = config.payload;
        this.node.on("input", this.inputHandler.bind(this));
    }
    SetResourceValue.prototype.inputHandler = function (msg) {
        var _this = this;
        var deviceId = this.deviceId || msg.deviceId;
        var resourceURI = this.resourceURI || msg.resourceURI;
        var payload = this.payload || msg.payload;
        this.connect.setResourceValue(deviceId, resourceURI, payload)
            .then(function (data) {
            msg.deviceId = deviceId;
            msg.resourceURI = resourceURI;
            msg.payload = data;
            _this.node.send(msg);
        })
            .catch(function (error) {
            _this.node.status({
                fill: "red",
                shape: "ring",
                text: "Error setting resource value"
            });
            _this.node.error(error);
        });
    };
    return SetResourceValue;
}());
module.exports = function (RED) {
    // tslint:disable-next-line:only-arrow-functions
    RED.nodes.registerType("set-resource-value", function (config) {
        var node = this;
        RED.nodes.createNode(node, config);
        // tslint:disable-next-line:no-unused-expression
        new SetResourceValue(node, config, RED);
    });
};
